#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-pool
version:              0.8.0.2
visibility:           public
id:                   hasql-pool-0.8.0.2-6EttXNAjke7oZeghKp8Xa
key:                  hasql-pool-0.8.0.2-6EttXNAjke7oZeghKp8Xa
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool
synopsis:             Pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  f3c5703b7f34777c6c5a8dc199214dbd
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:
    Hasql.Pool.Prelude Hasql.Pool.TimeExtras.IO
    Hasql.Pool.TimeExtras.Conversions

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-pool-0.8.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-pool-0.8.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-pool-0.8.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.8.0.2-6EttXNAjke7oZeghKp8Xa
depends:
    base-4.18.2.1 hasql-1.6.1.1-I6m7Cir6AuUG3tRQxJ9Bye stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

